@@ -5,6 +5,9 @@ from ..algebra import dagger
 
 def get_selfenergy(self,energy,lead=0,delta=None,pristine=False):
    """Return self energy of iesim lead"""
+   # in case you use a dummy selfenergy
+   if self.use_minimal_selfenergy:
+       return minimal_selfenergy(self,lead=lead)
    if delta is None:  delta = self.delta
 # if the interpolation function has been created
    if self.interpolated_selfenergy:
@@ -32,3 +35,21 @@ def get_selfenergy(self,energy,lead=0,delta=None,pristine=False):
 
 
 
+
+
+def minimal_selfenergy(self,lead=0,**kwargs):
+    """Function returning a minimal selfenergy"""
+    print("Using a dummy metallic selfenergy")
+    if not self.use_minimal_selfenergy: raise # make sure this is ok
+    gamma = self.minimal_selfenergy_gamma # get the gamma
+    # reescale for compatibility with everything else
+    if lead==0: 
+        scale = self.scale_lc**2
+        n = self.left_inter.shape[0]
+    elif lead==1: 
+        scale = self.scale_rc**2
+        n = self.right_inter.shape[0]
+    out = np.identity(n,dtype=np.complex) # output matrix
+    out = -scale*gamma*out*1j # multiply
+    return out
+
